Source-Changes-HG archive

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index][Old Index]

[src/netbsd-1-5]: src/sys/dev/pci Pullup 1.19 [thorpej/tsutsui]:



details:   https://anonhg.NetBSD.org/src/rev/0328c4bb1b45
branches:  netbsd-1-5
changeset: 490009:0328c4bb1b45
user:      tv <tv%NetBSD.org@localhost>
date:      Mon Oct 30 22:51:34 2000 +0000

description:
Pullup 1.19 [thorpej/tsutsui]:
Increase initial Tx drain threshold to 512 bytes.
My macppc complains about transmit FIFO underrun every time.

diffstat:

 sys/dev/pci/if_sip.c |  6 +++---
 1 files changed, 3 insertions(+), 3 deletions(-)

diffs (27 lines):

diff -r d498c9693c69 -r 0328c4bb1b45 sys/dev/pci/if_sip.c
--- a/sys/dev/pci/if_sip.c      Mon Oct 30 22:47:48 2000 +0000
+++ b/sys/dev/pci/if_sip.c      Mon Oct 30 22:51:34 2000 +0000
@@ -1,4 +1,4 @@
-/*     $NetBSD: if_sip.c,v 1.11.4.2 2000/09/28 16:42:55 thorpej Exp $  */
+/*     $NetBSD: if_sip.c,v 1.11.4.3 2000/10/30 22:51:34 tv Exp $       */
 
 /*-
  * Copyright (c) 1999 Network Computer, Inc.
@@ -1492,7 +1492,7 @@
        }
        if (sc->sc_tx_drain_thresh == 0) {
                /*
                 * Start at a drain threshold of 128 bytes.  We will
                 * increase it if a DMA underrun occurs.
                 *
                 * XXX The minimum value of this variable should be
@@ -1501,7 +1501,7 @@
                 * may trash the first few outgoing packets if the
                 * PCI bus is saturated.
                 */
-               sc->sc_tx_drain_thresh = 4;
+               sc->sc_tx_drain_thresh = 512 / 32;
        }
 
        /*
@@ -1492,7 +1492,7 @@
        if (sc->sc_tx_drain_thresh == 0) {
                /*
-                * Start at a drain threshold of 128 bytes.  We will
+                * Start at a drain threshold of 512 bytes.  We will
                 * increase it if a DMA underrun occurs.
                 *



Home | Main Index | Thread Index | Old Index